==> veriloggen-1.8.7.tar.gz: veriloggen-1.8.7/tests/extension/thread_/method/thread_method.py <==
from __future__ import absolute_import
from __future__ import print_function
import sys
import os

# the next line can be removed after installation
sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.dirname(
    os.path.dirname(os.path.dirname(os.path.abspath(__file__)))))))

from veriloggen import *
import veriloggen.thread as vthread

import math


class MyCounter(object):

    def __init__(self, m, clk, rst, maxval=256):
        self.m = m
        self.clk = clk
        self.rst = rst
        self.width = int(math.ceil(math.log(maxval, 2)))
        self.count = self.m.TmpReg(self.width, initval=0)

        # clock synchronous statement
        self.seq = TmpSeq(m, clk, rst)
        self.seq(
            self.count.inc()
        )

    def plus_value(self, offset=1):
        return self.count + offset


def mkLed():
    m = Module('blinkled')
    clk = m.Input('CLK')
    rst = m.Input('RST')
    led = m.OutputReg('LED', 8, initval=0)

    my_counter = MyCounter(m, clk, rst)

    def blink(times):
        led.value = 0
        for i in range(times):
            led.value = my_counter.plus_value(10)
            print("led = ", led)

    th = vthread.Thread(m, 'th_blink', clk, rst, blink)
    fsm = th.start(10)

    return m


def mkTest():
    m = Module('test')

    # target instance
    led = mkLed()

    # copy paras and ports
    params = m.copy_params(led)
    ports = m.copy_sim_ports(led)

    clk = ports['CLK']
    rst = ports['RST']

    uut = m.Instance(led, 'uut',
                     params=m.connect_params(led),
                     ports=m.connect_ports(led))

    simulation.setup_waveform(m, uut)
    simulation.setup_clock(m, clk, hperiod=5)
    init = simulation.setup_reset(m, rst, m.make_reset(), period=100)

    init.add(
        Delay(10000),
        Systask('finish'),
    )

    return m


if __name__ == '__main__':
    test = mkTest()
    verilog = test.to_verilog('tmp.v')
    print(verilog)

    sim = simulation.Simulator(test)
    rslt = sim.run()
    print(rslt)

==> veriloggen-1.9.5.tar.gz: veriloggen-1.9.5/tests/extension/thread_/method/thread_method.py <==
from __future__ import absolute_import
from __future__ import print_function
import sys
import os

# the next line can be removed after installation
sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.dirname(
    os.path.dirname(os.path.dirname(os.path.abspath(__file__)))))))

from veriloggen import *
import veriloggen.thread as vthread

import math


class MyCounter(object):

    def __init__(self, m, clk, rst, maxval=256):
        self.m = m
        self.clk = clk
        self.rst = rst
        self.width = int(math.ceil(math.log(maxval, 2)))
        self.count = self.m.TmpReg(self.width, initval=0)

        # clock synchronous statement
        self.seq = TmpSeq(m, clk, rst)
        self.seq(
            self.count.inc()
        )

    def plus_value(self, offset=1):
        return self.count + offset


def mkLed():
    m = Module('blinkled')
    clk = m.Input('CLK')
    rst = m.Input('RST')
    led = m.OutputReg('LED', 8, initval=0)

    my_counter = MyCounter(m, clk, rst)

    def blink(times):
        led.value = 0
        for i in range(times):
            led.value = my_counter.plus_value(10)
            print("led = ", led)

    th = vthread.Thread(m, 'th_blink', clk, rst, blink)
    fsm = th.start(10)

    return m


def mkTest():
    m = Module('test')

    # target instance
    led = mkLed()

    # copy paras and ports
    params = m.copy_params(led)
    ports = m.copy_sim_ports(led)

    clk = ports['CLK']
    rst = ports['RST']

    uut = m.Instance(led, 'uut',
                     params=m.connect_params(led),
                     ports=m.connect_ports(led))

    # simulation.setup_waveform(m, uut)
    simulation.setup_clock(m, clk, hperiod=5)
    init = simulation.setup_reset(m, rst, m.make_reset(), period=100)

    init.add(
        Delay(10000),
        Systask('finish'),
    )

    return m


if __name__ == '__main__':
    test = mkTest()
    verilog = test.to_verilog('tmp.v')
    print(verilog)

    sim = simulation.Simulator(test)
    rslt = sim.run()
    print(rslt)
